==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebIconButtonDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebButtonBaseDescriptionMetadata } from "./WebButtonBaseDescriptionMetadata";
import { WebIconButtonDescription } from "./WebIconButtonDescription";
/**
 * @hidden
 */
var WebIconButtonDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebIconButtonDescriptionMetadata, _super);
    function WebIconButtonDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebIconButtonDescriptionMetadata.b = function (a) {
        if (WebIconButtonDescriptionMetadata.a == null) {
            WebIconButtonDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebIconButtonDescriptionMetadata.c(WebIconButtonDescriptionMetadata.a);
        }
        if (a.k(WebIconButtonDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebIconButtonDescriptionMetadata.a);
    };
    WebIconButtonDescriptionMetadata.c = function (a) {
        WebButtonBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:IconButton");
        a.item("__tagNameWC", "String:igc-icon-button");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("IconName", "(wc:Name)String");
        a.item("Collection", "String");
        a.item("Mirrored", "Boolean");
        a.item("Variant", "ExportedType:string:IconButtonVariant");
        a.item("Variant@stringUnion", "WebComponents;React");
        a.item("Variant@names", "Flat;Contained;Outlined");
    };
    WebIconButtonDescriptionMetadata.d = function (a) {
        WebIconButtonDescriptionMetadata.b(a);
        a.ac("WebIconButton", function () { return new WebIconButtonDescription(); });
        a.ab("WebIconButton", WebIconButtonDescriptionMetadata.a);
    };
    WebIconButtonDescriptionMetadata.$t = markType(WebIconButtonDescriptionMetadata, 'WebIconButtonDescriptionMetadata');
    WebIconButtonDescriptionMetadata.a = null;
    return WebIconButtonDescriptionMetadata;
}(Base));
export { WebIconButtonDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebIconButtonDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebButtonBaseDescriptionMetadata } from "./WebButtonBaseDescriptionMetadata";
import { WebIconButtonDescription } from "./WebIconButtonDescription";
/**
 * @hidden
 */
var WebIconButtonDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebIconButtonDescriptionMetadata, _super);
    function WebIconButtonDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebIconButtonDescriptionMetadata.b = function (a) {
        if (WebIconButtonDescriptionMetadata.a == null) {
            WebIconButtonDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebIconButtonDescriptionMetadata.c(WebIconButtonDescriptionMetadata.a);
        }
        if (a.k(WebIconButtonDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebIconButtonDescriptionMetadata.a);
    };
    WebIconButtonDescriptionMetadata.c = function (a) {
        WebButtonBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:IconButton");
        a.item("__tagNameWC", "String:igc-icon-button");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("IconName", "(wc:Name)String");
        a.item("Collection", "String");
        a.item("Mirrored", "Boolean");
        a.item("Variant", "ExportedType:string:IconButtonVariant");
        a.item("Variant@stringUnion", "WebComponents;React");
        a.item("Variant@names", "Contained;Flat;Outlined");
    };
    WebIconButtonDescriptionMetadata.d = function (a) {
        WebIconButtonDescriptionMetadata.b(a);
        a.ae("WebIconButton", function () { return new WebIconButtonDescription(); });
        a.ad("WebIconButton", WebIconButtonDescriptionMetadata.a);
    };
    WebIconButtonDescriptionMetadata.$t = markType(WebIconButtonDescriptionMetadata, 'WebIconButtonDescriptionMetadata');
    WebIconButtonDescriptionMetadata.a = null;
    return WebIconButtonDescriptionMetadata;
}(Base));
export { WebIconButtonDescriptionMetadata };
